@@ -3,7 +3,7 @@ package HTML::FormFu::Constraint::Length;
 use strict;
 use base 'HTML::FormFu::Constraint';
 
-__PACKAGE__->mk_accessors(qw/minimum maximum/);
+__PACKAGE__->mk_item_accessors( qw( minimum maximum ) );
 
 *min = \&minimum;
 *max = \&maximum;
@@ -13,14 +13,11 @@ sub constrain_value {
 
     return 1 if !defined $value || $value eq '';
 
-    my $min = $self->minimum;
-    my $max = $self->maximum;
-
-    if ( defined $min ) {
+    if ( defined ( my $min = $self->minimum ) ) {
         return 0 if length $value < $min;
     }
 
-    if ( defined $max ) {
+    if ( defined ( my $max = $self->maximum ) ) {
         return 0 if length $value > $max;
     }
 
@@ -63,7 +60,7 @@ L</max> is an alias for L</maximum>.
 
 Is a sub-class of, and inherits methods from L<HTML::FormFu::Constraint>
 
-L<HTML::FormFu::FormFu>
+L<HTML::FormFu>
 
 =head1 AUTHOR
 
