@@ -4,28 +4,29 @@ use strict;
 use base 'HTML::FormFu::Element::_Field';
 use Class::C3;
 
-use HTML::FormFu::ObjectUtil qw/ _coerce /;
-use HTML::FormFu::Util qw/ process_attrs /;
+use HTML::FormFu::ObjectUtil qw( _coerce );
+use HTML::FormFu::Util qw( process_attrs );
 
-__PACKAGE__->mk_accessors(qw/ field_type /);
+__PACKAGE__->mk_item_accessors( qw( field_type ) );
 
-__PACKAGE__->mk_attr_accessors(qw/ checked size maxlength alt /);
+__PACKAGE__->mk_attr_accessors( qw( checked size maxlength alt ) );
 
 sub new {
     my $self = shift->next::method(@_);
 
-    $self->filename('input');
-    $self->field_filename('input_tag');
+    $self->filename      ( 'input' );
+    $self->field_filename( 'input_tag' );
 
     return $self;
 }
 
 sub render_data_non_recursive {
-    my $self = shift;
+    my ( $self, $args ) = @_;
 
     my $render = $self->next::method( {
-            field_type => $self->field_type,
-            @_ ? %{ $_[0] } : () } );
+        field_type => $self->field_type,
+        $args ? %$args : (),
+    } );
 
     return $render;
 }
@@ -35,10 +36,9 @@ sub string {
 
     $args ||= {};
 
-    my $render
-        = exists $args->{render_data}
-        ? $args->{render_data}
-        : $self->render_data;
+    my $render = exists $args->{render_data} ? $args->{render_data}
+               :                               $self->render_data
+               ;
 
     # field wrapper template - start
 
@@ -111,7 +111,7 @@ L<HTML::FormFu::Element::Text>.
 Is a sub-class of, and inherits methods from 
 L<HTML::FormFu::Element::_Field>, L<HTML::FormFu::Element>
 
-L<HTML::FormFu::FormFu>
+L<HTML::FormFu>
 
 =head1 AUTHOR
 
