@@ -5,8 +5,8 @@ use base 'HTML::FormFu::Processor';
 use Class::C3;
 
 use HTML::FormFu::Exception::Transformer;
-use Scalar::Util qw/ blessed /;
-use Carp qw/ croak /;
+use Scalar::Util qw( blessed );
+use Carp qw( croak );
 
 sub process {
     my ( $self, $values, $params ) = @_;
@@ -17,7 +17,8 @@ sub process {
     if ( ref $values eq 'ARRAY' ) {
         my @return;
         for my $value (@$values) {
-            my ($return) = eval { $self->transformer( $value, $params ); };
+            my ($return) = eval { $self->transformer( $value, $params ) };
+            
             if ($@) {
                 push @errors, $self->return_error($@);
                 push @return, undef;
@@ -29,7 +30,8 @@ sub process {
         $return = \@return;
     }
     else {
-        ($return) = eval { $self->transformer( $values, $params ); };
+        ($return) = eval { $self->transformer( $values, $params ) };
+        
         if ($@) {
             push @errors, $self->return_error($@);
         }
